@@ -2,18 +2,17 @@
 
 import enum
 import logging
-import os.path
+import os
 import pathlib
 
-from qtpy import QtCore, QtGui, QtWidgets
-from qtpy.QtCore import Q_ENUMS, Property, Qt, Slot
-
 import ophyd
 import pcdsutils
 import pydm.display
 import pydm.exception
 import pydm.utilities
 from pcdsutils.qt import forward_property
+from qtpy import QtCore, QtGui, QtWidgets
+from qtpy.QtCore import Q_ENUMS, Property, Qt, Slot
 
 from . import cache
 from . import panel as typhos_panel
@@ -34,11 +33,11 @@ _DisplayTypes = utils.pyqt_class_from_enum(DisplayTypes)
 DisplayTypes.names = [view.name for view in DisplayTypes]
 
 DEFAULT_TEMPLATES = {
-    name: [(utils.ui_dir / f'{name}.ui').resolve()]
+    name: [(utils.ui_dir / 'core' / f'{name}.ui').resolve()]
     for name in DisplayTypes.names
 }
 
-DETAILED_TREE_TEMPLATE = (utils.ui_dir / 'detailed_tree.ui').resolve()
+DETAILED_TREE_TEMPLATE = (utils.ui_dir / 'core' / 'detailed_tree.ui').resolve()
 DEFAULT_TEMPLATES['detailed_screen'].append(DETAILED_TREE_TEMPLATE)
 
 DEFAULT_TEMPLATES_FLATTEN = [f for _, files in DEFAULT_TEMPLATES.items()
@@ -324,6 +323,11 @@ class TyphosDisplayConfigButton(TyphosToolButton):
         base_menu.addSeparator()
         self.create_hide_empty_menu(panels, base_menu)
 
+        if utils.DEBUG_MODE:
+            base_menu.addSection('Debug')
+            action = base_menu.addAction('&Copy to clipboard')
+            action.triggered.connect(display.copy_to_clipboard)
+
         return base_menu
 
 
@@ -837,7 +841,7 @@ class TyphosDeviceDisplay(utils.TyphosBase, widgets.TyphosDesignerMixin,
                 # If we have a previously defined template
                 if self._current_template is not None:
                     # Fallback to it so users have a choice
-                    self._load_template(self._current_template)
+                    widget = self._load_template(self._current_template)
                     pydm.exception.raise_to_operator(ex)
                 else:
                     widget = QtWidgets.QWidget()
@@ -846,6 +850,11 @@ class TyphosDeviceDisplay(utils.TyphosBase, widgets.TyphosDesignerMixin,
         if widget:
             widget.setObjectName('display_widget')
 
+            if widget.layout() is None and widget.minimumSize().width() == 0:
+                # If the widget has no layout, use a fixed size for it.
+                # Without this, the widget may not display at all.
+                widget.setMinimumSize(widget.size())
+
         self._display_widget = widget
         self._current_template = template
 
@@ -1131,6 +1140,26 @@ class TyphosDeviceDisplay(utils.TyphosBase, widgets.TyphosDesignerMixin,
             if not utils.is_standard_template(template)
         ]
 
+    def to_image(self):
+        """
+        Return the entire display as a QtGui.QImage.
+
+        Returns
+        -------
+        QtGui.QImage
+            The display, as an image.
+        """
+        if self._display_widget is not None:
+            return utils.widget_to_image(self._display_widget)
+
+    @Slot()
+    def copy_to_clipboard(self):
+        """Copy the display image to the clipboard."""
+        image = self.to_image()
+        if image is not None:
+            clipboard = QtGui.QGuiApplication.clipboard()
+            clipboard.setImage(image)
+
     @Slot(object)
     def _tx(self, value):
         """Receive information from happi channel."""
