@@ -14,12 +14,11 @@ import functools
 import logging
 from functools import partial
 
-from qtpy import QtCore, QtWidgets
-from qtpy.QtCore import Q_ENUMS, Property
-
 import ophyd
 from ophyd import Kind
 from ophyd.signal import EpicsSignal, EpicsSignalRO
+from qtpy import QtCore, QtWidgets
+from qtpy.QtCore import Q_ENUMS, Property
 
 from . import display, utils
 from .cache import get_global_widget_type_cache
@@ -207,9 +206,6 @@ class SignalPanel(QtWidgets.QGridLayout):
         sig_info['widget_info'] = info
         row = sig_info['row']
 
-        read = info.read_cls(**info.read_kwargs)
-        write = info.write_cls(**info.write_kwargs) if info.write_cls else None
-
         # Remove the 'loading...' animation if it's there
         item = self.itemAtPosition(row, self.COL_SETPOINT)
         if item:
@@ -218,10 +214,12 @@ class SignalPanel(QtWidgets.QGridLayout):
                 self.removeItem(item)
                 val_widget.deleteLater()
 
-        # And add the new widgets to the layout:
-        widgets = [None, read]
-        if write is not None:
-            widgets += [write]
+        widgets = [None]
+        if info.read_cls is not None:
+            widgets.append(info.read_cls(**info.read_kwargs))
+
+        if info.write_cls is not None:
+            widgets.append(info.write_cls(**info.write_kwargs))
 
         self._update_row(row, widgets)
 
@@ -276,7 +274,17 @@ class SignalPanel(QtWidgets.QGridLayout):
         logger.debug("Adding signal %s (%s)", signal.name, name)
 
         label = self._create_row_label(name, name, tooltip)
-        row = self.add_row(label, utils.TyphosLoading())
+        loading = utils.TyphosLoading(
+            timeout_message='Connection timed out.'
+        )
+
+        loading_tooltip = ['Connecting to:'] + list(set(
+            getattr(signal, attr)
+            for attr in ('setpoint_pvname', 'pvname') if hasattr(signal, attr)
+        ))
+        loading.setToolTip('\n'.join(loading_tooltip))
+
+        row = self.add_row(label, loading)
         self.signal_name_to_info[signal.name] = dict(
             row=row,
             signal=signal,
